/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2005-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
dojo.provide("net.jazz.ajax.ui.internal.Button");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dijit.Menu");

(function() {
/*
 * Constructor:
 * var button = new net.jazz.ajax.ui.internal.Button({args});
 * 
 * args:
 * 
 *  href: string (href will supercede callback if both passed in)
 * 		OR
 * 	callback: string OR function
 * 	
 * 	imageClass: string
 * 	buttonText: string
 * 	boldFirstWord: boolean
 * 	size: "small" or "large"
 * 	disabled: boolean
 */
dojo.declare("net.jazz.ajax.ui.internal.Button",
	[dijit._Widget, dijit._Templated], {

	templatePath: dojo.moduleUrl("net.jazz.ajax", "ui/internal/templates/Button.html"),

	postCreate: function() {
		
		if (this.size == "large") {
			dojo.addClass(this._buttonWrapper,"largeButton");
		} else {
			dojo.addClass(this._buttonWrapper,"smallButton");
		}
		
		dojo.addClass(this._image,this.imageClass);
		this._updateDisabled();
		
		if (this.boldFirstWord) {
			var firstSpace = this.buttonText.indexOf(" ");
			if (this.size == "large") {
				this._label.innerHTML = "<b style=\"font-size: 11pt\">" + this.buttonText.substring(0,firstSpace) + " </b><nobr>" + this.buttonText.substring(firstSpace+1)+"</nobr>";
			} else {
				this._label.innerHTML = "<b>" + this.buttonText.substring(0,firstSpace) + "</b>" + this.buttonText.substring(firstSpace);
			}
		} else {
			this._label.innerHTML = this.buttonText;
		}
		if(this.href) this.domNode.href = this.href;
	},
	populateDropDown: function(values) {
		this._menuArrow.style.display = "block";
		this.dropDownValues = values;
	},
	setDisabled: function (disabled) {
		this.disabled = disabled;
		this._updateDisabled();
	},
	destroy: function() {
		this.inherited(arguments);
	},
	_updateDisabled: function() {
		if (this.disabled) {
			dojo.addClass(this.domNode,"net-jazz-ajax-DisabledButton");
		} else {
			dojo.removeClass(this.domNode,"net-jazz-ajax-DisabledButton");
		}
	},
	makeUrlsUnique: function() {
		var ts = Date.parse(new  Date().toString());
		if(this.href && this._button) {
			this.href = this.href.replace(/&ts=([0-9]+)/, "") + "&ts=" + ts + "0";
			this._button.href = this.href;
		}
		if(this.dropDownValues) {
			for(var i=0;i< this.dropDownValues.length;i++) {
				if (this.dropDownValues[i]) {
					this.dropDownValues[i].url = this.dropDownValues[i].url.replace(/&ts=([0-9]+)/, "") + "&ts=" + ts + "" + (i+1);
					if(this.dropDownValues[i].menuItem) {
						this.dropDownValues[i].menuItem.url =this.dropDownValues[i].url 
					}
				}
			}
		}
	}, 
	_handleClick: function(event) {
		if (this.disabled) {
			event.preventDefault();
			this.domNode.blur();
			return;
		}
		if (!this.href) {
			event.preventDefault();
			this.callback(event);	
		} else if (dojo.isIE) {
			event.preventDefault();
			location.href = this.href;
		}
		// else if firefox && href, let the link fire
	},
	_openMenu: function (event) {
		if (this.menuOpen) return;
		this.menuOpen = true;
		dojo.stopEvent(event);
		this._button.blur();
		if (!this._buttonMenu) {
			var menu = new dijit.Menu({onExecute: dojo.hitch(this,this._closeMenu)});
			dojo.addClass(menu.domNode,"net-jazz-ajax-Button-Menu");
			this._menu = menu;
			var dropDownValues = this.dropDownValues;
			for (var i = 0; i < dropDownValues.length; i++) {
				var item = new dijit.MenuItem({label: dropDownValues[i].label, onClick: function() {location.href = this.url}})
				item.url = this.dropDownValues[i].url;
				menu.addChild(item);
				if (dropDownValues[i].iconUrl) {
					var img = new Image();
					img.src = dropDownValues[i].iconUrl;
					item.iconNode.appendChild(img);	
				}
				this.dropDownValues[i].menuItem = item;
			}
			var buttonMenu = new net.jazz.ajax.ui.internal.ButtonMenu();
			buttonMenu._menuArea.appendChild(this._menu.domNode);
			this._buttonMenu = buttonMenu;
		} 
		document.body.appendChild(this._buttonMenu.domNode);
		var pos = dojo.coords(this._buttonWrapper, true);
		this._menu.domNode.style.width = pos.w - 4 + "px";
		this._buttonMenu.domNode.style.paddingTop = pos.h - 7 + "px";
		this._buttonMenu.domNode.style.top = pos.y + "px";
		this._buttonMenu.domNode.style.left = pos.x + "px";
		if (!this._menuCloseOnBody)
			this._menuCloseOnBody = this.connect(document.body,"onclick",this._closeMenu);
		if (!this._menuCloseOnMenu)
			this._menuCloseOnMenu = this.connect(this,"_onblur",this._closeMenu);
	},
	_closeMenu: function(event) {
		document.body.removeChild(this._buttonMenu.domNode);
		this.disconnect(this._menuCloseOnBody);
		this.disconnect(this._menuCloseOnMenu);
		this._menuCloseOnBody = null;
		this._menuCloseOnMenu = null;
		this.menuOpen = false;
	}
});

dojo.declare("net.jazz.ajax.ui.internal.ButtonMenu",
	[dijit._Widget, dijit._Templated], {
	templatePath: dojo.moduleUrl("net.jazz.ajax", "ui/internal/templates/ButtonMenu.html")
	
});

})();
